cloudtasks library

The Google Cloud client for the Cloud Tasks API.

Manages the execution of large numbers of distributed requests.

Classes

AppEngineHttpRequest
App Engine HTTP request.
AppEngineRouting
App Engine Routing.
Attempt
The status of a task attempt.
CloudTasks
Cloud Tasks allows developers to manage the execution of background work in their applications.
CreateQueueRequest
Request message for CreateQueue.
CreateTaskRequest
Request message for CreateTask.
DeleteQueueRequest
Request message for DeleteQueue.
DeleteTaskRequest
Request message for deleting a task using DeleteTask.
GetQueueRequest
Request message for GetQueue.
GetTaskRequest
Request message for getting a task using GetTask.
HttpMethod
The HTTP method used to deliver the task.
HttpRequest
HTTP request.
ListQueuesRequest
Request message for ListQueues.
ListQueuesResponse
Response message for ListQueues.
ListTasksRequest
Request message for listing tasks using ListTasks.
ListTasksResponse
Response message for listing tasks using ListTasks.
OauthToken
Contains information needed for generating an OAuth token. This type of authorization should generally only be used when calling Google APIs hosted on *.googleapis.com.
OidcToken
Contains information needed for generating an OpenID Connect token. This type of authorization can be used for many scenarios, including calling Cloud Run, or endpoints where you intend to validate the token yourself.
PauseQueueRequest
Request message for PauseQueue.
PurgeQueueRequest
Request message for PurgeQueue.
Queue
A queue is a container of related tasks. Queues are configured to manage how those tasks are dispatched. Configurable properties include rate limits, retry options, queue types, and others.
Queue_State
State of the queue.
RateLimits
Rate limits.
ResumeQueueRequest
Request message for ResumeQueue.
RetryConfig
Retry config.
RunTaskRequest
Request message for forcing a task to run now using RunTask.
StackdriverLoggingConfig
Configuration options for writing logs to Stackdriver Logging.
Task
A unit of scheduled work.
Task_View
The view specifies a subset of Task data.
UpdateQueueRequest
Request message for UpdateQueue.

Exceptions / Errors

BadGatewayException
Exception thrown when the server returns a "502 Bad Gateway" response.
BadRequestException
Exception thrown when the server returns a "400 Bad Request" response.
CancelledException
Exception thrown when the server returns a "499 Cancelled" response.
ConfigurationException
Exception thrown when a method is called without correct configuration.
ConflictException
Exception thrown when the server returns a "409 Conflict" response.
ForbiddenException
Exception thrown when the server returns a "403 Forbidden" response.
GatewayTimeoutException
Exception thrown when the server returns a "504 Gateway Timeout" response.
InternalServerErrorException
Exception thrown when the server returns a "500 Internal Server Error" response.
LengthRequiredException
Exception thrown when the server returns a "411 Length Required" response.
MethodNotAllowedException
Exception thrown when the server returns a "405 Method Not Allowed" response.
NotFoundException
Exception thrown when the server returns a "404 Not Found" response.
NotImplementedException
Exception thrown when the server returns a "501 Not Implemented" response.
NotModifiedException
Exception thrown when the server returns a "304 Not Modified" response.
PreconditionFailedException
Exception thrown when the server returns a "412 Precondition Failed" response.
RequestRangeNotSatisfiableException
Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
RequestTimeoutException
Exception thrown when the server returns a "408 Request Timeout" response.
ServiceException
Exception thrown when an API call fails.
ServiceUnavailableException
Exception thrown when the server returns a "503 Service Unavailable" response.
TooManyRequestsException
Exception thrown when the server returns a "429 Too Many Requests" response.
UnauthorizedException
Exception thrown when the server returns a "401 Unauthorized" response.