appEngineRouting property

AppEngineRouting? appEngineRouting
final

Task-level setting for App Engine routing.

  • If google.cloud.tasks.v2.Queue.app_engine_routing_override, this value is used for all tasks in the queue, no matter what the setting is for the google.cloud.tasks.v2.AppEngineHttpRequest.app_engine_routing.

Implementation

final AppEngineRouting? appEngineRouting;