service property
App service.
By default, the task is sent to the service which is the default service when the task is attempted.
For some queues or tasks which were created using the App Engine
Task Queue API, host is not
parsable into service,
version, and
instance. For example,
some tasks which were created using the App Engine SDK use a custom domain
name; custom domains are not parsed by Cloud Tasks. If
host is not parsable, then
service,
version, and
instance are the empty
string.
Implementation
final String service;