Attempt class final

The status of a task attempt.

Constructors

Attempt({Timestamp? scheduleTime, Timestamp? dispatchTime, Timestamp? responseTime, Status? responseStatus})
Attempt.fromJson(Object? j)
factory

Properties

dispatchTime → Timestamp?
Output only. The time that this attempt was dispatched.
final
hashCode → int
The hash code for this object.
no setterinherited
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
responseStatus → Status?
Output only. The response from the worker for this attempt.
final
responseTime → Timestamp?
Output only. The time that this attempt response was received.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleTime → Timestamp?
Output only. The time that this attempt was scheduled.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String