responseStatus property

Status? responseStatus
final

Output only. The response from the worker for this attempt.

If response_time is unset, then the task has not been attempted or is currently running and the response_status field is meaningless.

Implementation

final Status? responseStatus;