CloudTasks class final

Cloud Tasks allows developers to manage the execution of background work in their applications.

Implementers

Constructors

CloudTasks({required Client client, Uri? endPoint, String? gcclVersion})
Creates a CloudTasks using client for transport.
CloudTasks.fromApiKey([String? apiKey])
Creates a CloudTasks that does authentication through an API key.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the client and cleans up any resources associated with it.
createQueue(CreateQueueRequest request) → Future<Queue>
Creates a queue.
createTask(CreateTaskRequest request) → Future<Task>
Creates a task and adds it to a queue.
deleteQueue(DeleteQueueRequest request) → Future<void>
Deletes a queue.
deleteTask(DeleteTaskRequest request) → Future<void>
Deletes a task.
getIamPolicy(GetIamPolicyRequest request) → Future<Policy>
Gets the access control policy for a Queue. Returns an empty policy if the resource exists and does not have a policy set.
getLocation(GetLocationRequest request) → Future<Location>
Gets information about a location.
getQueue(GetQueueRequest request) → Future<Queue>
Gets a queue.
getTask(GetTaskRequest request) → Future<Task>
Gets a task.
listLocations(ListLocationsRequest request) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
listQueues(ListQueuesRequest request) → Future<ListQueuesResponse>
Lists queues.
listTasks(ListTasksRequest request) → Future<ListTasksResponse>
Lists the tasks in a queue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseQueue(PauseQueueRequest request) → Future<Queue>
Pauses the queue.
purgeQueue(PurgeQueueRequest request) → Future<Queue>
Purges a queue by deleting all of its tasks.
resumeQueue(ResumeQueueRequest request) → Future<Queue>
Resume a queue.
runTask(RunTaskRequest request) → Future<Task>
Forces a task to run now.
setIamPolicy(SetIamPolicyRequest request) → Future<Policy>
Sets the access control policy for a Queue. Replaces any existing policy.
testIamPermissions(TestIamPermissionsRequest request) → Future<TestIamPermissionsResponse>
Returns permissions that a caller has on a Queue. If the resource does not exist, this will return an empty set of permissions, not a NOT_FOUND error.
toString() → String
A string representation of this object.
inherited
updateQueue(UpdateQueueRequest request) → Future<Queue>
Updates a queue.

Operators

operator ==(Object other) → bool
The equality operator.
inherited