getIamPolicy method

Future<Policy> getIamPolicy(
  1. GetIamPolicyRequest request
)

Gets the access control policy for a Queue. Returns an empty policy if the resource exists and does not have a policy set.

Authorization requires the following Google IAM permission on the specified resource parent:

  • cloudtasks.queues.getIamPolicy

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Policy> getIamPolicy(GetIamPolicyRequest request) async {
  final url = _endPoint.replace(path: '/v2/${request.resource}:getIamPolicy');
  final response = await _client.post(url, body: request);
  return Policy.fromJson(response);
}