resumeQueue method

Future<Queue> resumeQueue(
  1. ResumeQueueRequest request
)

Resume a queue.

This method resumes a queue after it has been PAUSED or DISABLED. The state of a queue is stored in the queue's state; after calling this method it will be set to RUNNING.

WARNING: Resuming many high-QPS queues at the same time can lead to target overloading. If you are resuming high-QPS queues, follow the 500/50/5 pattern described in Managing Cloud Tasks Scaling Risks.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Queue> resumeQueue(ResumeQueueRequest request) async {
  final url = _endPoint.replace(path: '/v2/${request.name}:resume');
  final response = await _client.post(url, body: request);
  return Queue.fromJson(response);
}