setIamPolicy method

Future<Policy> setIamPolicy(
  1. SetIamPolicyRequest request
)

Sets the access control policy for a Queue. Replaces any existing policy.

Note: The Cloud Console does not check queue-level IAM permissions yet. Project-level permissions are required to use the Cloud Console.

Authorization requires the following Google IAM permission on the specified resource parent:

  • cloudtasks.queues.setIamPolicy

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<Policy> setIamPolicy(SetIamPolicyRequest request) async {
  final url = _endPoint.replace(path: '/v2/${request.resource}:setIamPolicy');
  final response = await _client.post(url, body: request);
  return Policy.fromJson(response);
}