CreateTaskRequest class final

Request message for CreateTask.

Constructors

CreateTaskRequest({required String parent, required Task? task, Task_View responseView = Task_View.$default})
CreateTaskRequest.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → String
Required. The queue name. For example: projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
responseView → Task_View
The response_view specifies which subset of the Task will be returned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → Task?
Required. The task to add.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String