task property
Required. The task to add.
Task names have the following format:
projects/PROJECT_ID/locations/LOCATION_ID/queues/QUEUE_ID/tasks/TASK_ID.
The user can optionally specify a task
name. If a name is not specified then
the system will generate a random unique task id, which will be set in the
task returned in the response.
If schedule_time is not set or
is in the past then Cloud Tasks will set it to the current time.
Task De-duplication:
Explicitly specifying a task ID enables task de-duplication. If
a task's ID is identical to that of an existing task or a task
that was deleted or executed recently then the call will fail
with ALREADY_EXISTS.
If the task's queue was created using Cloud Tasks, then another task with
the same name can't be created for ~1hour after the original task was
deleted or executed. If the task's queue was created using queue.yaml or
queue.xml, then another task with the same name can't be created
for ~9days after the original task was deleted or executed.
Because there is an extra lookup cost to identify duplicate task
names, these CreateTask
calls have significantly increased latency. Using hashed strings for the
task id or for the prefix of the task id is recommended. Choosing task ids
that are sequential or have sequential prefixes, for example using a
timestamp, causes an increase in latency and error rates in all
task commands. The infrastructure relies on an approximately
uniform distribution of task ids to store and serve tasks
efficiently.
Implementation
final Task? task;