HttpMethod class final

The HTTP method used to deliver the task.

Constructors

HttpMethod(String value)
const
HttpMethod.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const HttpMethod
The default value for HttpMethod.
delete → const HttpMethod
HTTP DELETE
get → const HttpMethod
HTTP GET
HTTP HEAD
httpMethodUnspecified → const HttpMethod
HTTP method unspecified
options → const HttpMethod
HTTP OPTIONS
patch → const HttpMethod
HTTP PATCH
post → const HttpMethod
HTTP POST
put → const HttpMethod
HTTP PUT