body property

Uint8List body
final

HTTP request body.

A request body is allowed only if the google.cloud.tasks.v2.HttpRequest.http_method is POST, PUT, or PATCH. It is an error to set body on a task with an incompatible HttpMethod.

Implementation

final Uint8List body;