headers property

Map<String, String> headers
final

HTTP request headers.

This map contains the header field names and values. Headers can be set when the google.cloud.tasks.v2beta3.CloudTasks.CreateTask.

These headers represent a subset of the headers that will accompany the task's HTTP request. Some HTTP request headers will be ignored or replaced.

A partial list of headers that will be ignored or replaced is:

  • Host: This will be computed by Cloud Tasks and derived from HttpRequest.url.
  • Content-Length: This will be computed by Cloud Tasks.
  • User-Agent: This will be set to "Google-Cloud-Tasks".
  • X-Google-*: Google use only.
  • X-AppEngine-*: Google use only.

Content-Type won't be set by Cloud Tasks. You can explicitly set Content-Type to a media type when the google.cloud.tasks.v2beta3.CloudTasks.CreateTask. For example, Content-Type can be set to "application/octet-stream" or "application/json".

Headers which can have multiple values (according to RFC2616) can be specified using comma-separated values.

The size of the headers must be less than 80KB.

Implementation

final Map<String, String> headers;