ListQueuesRequest class final

Request message for ListQueues.

Constructors

ListQueuesRequest({required String parent, String filter = '', int pageSize = 0, String pageToken = ''})
ListQueuesRequest.fromJson(Object? j)
factory

Properties

filter → String
filter can be used to specify a subset of queues. Any Queue field can be used as a filter and several operators as supported. For example: <=, <, >=, >, !=, =, :. The filter syntax is the same as described in Stackdriver's Advanced Logs Filters.
final
hashCode → int
The hash code for this object.
no setterinherited
pageSize → int
Requested page size.
final
pageToken → String
A token identifying the page of results to return.
final
parent → String
Required. The location name. For example: projects/PROJECT_ID/locations/LOCATION_ID
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String