pageSize property

int pageSize
final

Requested page size.

The maximum page size is 9800. If unspecified, the page size will be the maximum. Fewer queues than requested might be returned, even if more queues exist; use the next_page_token in the response to determine if more queues exist.

Implementation

final int pageSize;