pageToken property

String pageToken
final

A token identifying the page of results to return.

To request the first page results, page_token must be empty. To request the next page of results, page_token must be the value of next_page_token returned from the previous call to ListQueues method. It is an error to switch the value of the filter while iterating through pages.

Implementation

final String pageToken;