pageSize property

int pageSize
final

Maximum page size.

Fewer tasks than requested might be returned, even if more tasks exist; use next_page_token in the response to determine if more tasks exist.

The maximum page size is 1000. If unspecified, the page size will be the maximum.

Implementation

final int pageSize;