disabled constant
Queue_State
const disabled
The queue is disabled.
A queue becomes DISABLED when
queue.yaml
or
queue.xml
is uploaded which does not contain the queue. You cannot directly disable
a queue.
When a queue is disabled, tasks can still be added to a queue but the tasks are not dispatched.
To permanently delete this queue and all of its tasks, call
DeleteQueue.
Implementation
static const disabled = Queue_State('DISABLED');