running constant

Queue_State const running

The queue is running. Tasks can be dispatched.

If the queue was created using Cloud Tasks and the queue has had no activity (method calls or task dispatches) for 30 days, the queue may take a few minutes to re-activate. Some method calls may return NOT_FOUND and tasks may not be dispatched for a few minutes until the queue has been re-activated.

Implementation

static const running = Queue_State('RUNNING');