RateLimits class final

Rate limits.

This message determines the maximum rate that tasks can be dispatched by a queue, regardless of whether the dispatch is a first task attempt or a retry.

Note: The debugging command, RunTask, will run a task even if the queue has reached its RateLimits.

Constructors

RateLimits({double maxDispatchesPerSecond = 0, int maxBurstSize = 0, int maxConcurrentDispatches = 0})
RateLimits.fromJson(Object? j)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxBurstSize → int
Output only. The max burst size.
final
maxConcurrentDispatches → int
The maximum number of concurrent tasks that Cloud Tasks allows to be dispatched for this queue. After this threshold has been reached, Cloud Tasks stops dispatching tasks until the number of concurrent requests decreases.
final
maxDispatchesPerSecond → double
The maximum rate at which tasks are dispatched from this queue.
final
qualifiedName → String
The fully qualified name of this message, i.e., google.protobuf.Duration or google.rpc.ErrorInfo.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

fullyQualifiedName → const String