RetryConfig class final
Retry config.
These settings determine when a failed task attempt is retried.
Constructors
- RetryConfig({int maxAttempts = 0, Duration? maxRetryDuration, Duration? minBackoff, Duration? maxBackoff, int maxDoublings = 0})
- RetryConfig.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttempts → int
-
Number of attempts per task.
final
- maxBackoff → Duration?
-
A task will be
scheduledfor retry betweenmin_backoffandmax_backoffduration after it fails, if the queue'sRetryConfigspecifies that the task should be retried.final - maxDoublings → int
-
The time between retries will double
max_doublingstimes.final - maxRetryDuration → Duration?
-
If positive,
max_retry_durationspecifies the time limit for retrying a failed task, measured from when the task was first attempted. Oncemax_retry_durationtime has passed and the task has been attemptedmax_attemptstimes, no further attempts will be made and the task will be deleted.final - minBackoff → Duration?
-
A task will be
scheduledfor retry betweenmin_backoffandmax_backoffduration after it fails, if the queue'sRetryConfigspecifies that the task should be retried.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String