maxAttempts property

int maxAttempts
final

Number of attempts per task.

Cloud Tasks will attempt the task max_attempts times (that is, if the first attempt fails, then there will be max_attempts - 1 retries). Must be >= -1.

If unspecified when the queue is created, Cloud Tasks will pick the default.

-1 indicates unlimited attempts.

This field has the same meaning as task_retry_limit in queue.yaml/xml.

Implementation

final int maxAttempts;