maxRetryDuration property
Duration?
maxRetryDuration
final
If positive, max_retry_duration specifies the time limit for
retrying a failed task, measured from when the task was first
attempted. Once max_retry_duration time has passed and the
task has been attempted
max_attempts times, no
further attempts will be made and the task will be deleted.
If zero, then the task age is unlimited.
If unspecified when the queue is created, Cloud Tasks will pick the default.
max_retry_duration will be truncated to the nearest second.
This field has the same meaning as task_age_limit in queue.yaml/xml.
Implementation
final Duration? maxRetryDuration;