appEngineHttpRequest property

AppEngineHttpRequest? appEngineHttpRequest
final

HTTP request that is sent to the App Engine app handler.

An App Engine task is a task that has AppEngineHttpRequest set.

Implementation

final AppEngineHttpRequest? appEngineHttpRequest;