dispatchCount property
Output only. The number of attempts dispatched.
This count includes attempts which have been dispatched but haven't received a response.
Implementation
final int dispatchCount;
Output only. The number of attempts dispatched.
This count includes attempts which have been dispatched but haven't received a response.
final int dispatchCount;