dispatchDeadline property
The deadline for requests sent to the worker. If the worker does not
respond by this deadline then the request is cancelled and the attempt
is marked as a DEADLINE_EXCEEDED failure. Cloud Tasks will retry the
task according to the RetryConfig.
Note that when the request is cancelled, Cloud Tasks will stop listening for the response, but whether the worker stops processing depends on the worker. For example, if the worker is stuck, it may not react to cancelled requests.
The default and maximum values depend on the type of request:
-
For
google.cloud.tasks.v2.HttpRequest, the default is 10 minutes. The deadline must be in the interval15 seconds, 30 minutes. -
For
google.cloud.tasks.v2.AppEngineHttpRequest, 0 indicates that the request has the default deadline. The default deadline depends on the scaling type of the service: 10 minutes for standard apps with automatic scaling, 24 hours for standard apps with manual and basic scaling, and 60 minutes for flex apps. If the request deadline is set, it must be in the interval15 seconds, 24 hours 15 seconds. Regardless of the task'sdispatch_deadline, the app handler will not run for longer than than the service's timeout. We recommend setting thedispatch_deadlineto at most a few seconds more than the app handler's timeout. For more information see Timeouts.
dispatch_deadline will be truncated to the nearest millisecond. The
deadline is an approximate deadline.
Implementation
final Duration? dispatchDeadline;