Task_View class final

The view specifies a subset of Task data.

When a task is returned in a response, not all information is retrieved by default because some data, such as payloads, might be desirable to return only when needed because of its large size or because of the sensitivity of data that it contains.

Constructors

Task_View(String value)
const
Task_View.fromJson(Object? json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNotDefault → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Object?
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

$default → const Task_View
The default value for Task_View.
basic → const Task_View
The basic view omits fields which can be large or can contain sensitive data.
full → const Task_View
All information is returned.
viewUnspecified → const Task_View
Unspecified. Defaults to BASIC.