basic constant

Task_View const basic

The basic view omits fields which can be large or can contain sensitive data.

This view does not include the google.cloud.tasks.v2.AppEngineHttpRequest.body. Bodies are desirable to return only when needed, because they can be large and because of the sensitivity of the data that you choose to store in it.

Implementation

static const basic = Task_View('BASIC');