createTask method

  1. @override
Future<Task> createTask(
  1. CreateTaskRequest request
)
override

Creates a task and adds it to a queue.

Tasks cannot be updated after creation; there is no UpdateTask command.

  • The maximum task size is 100KB.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Task> createTask(CreateTaskRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_createTask case final createTask?) {
    return createTask(request);
  }
  throw UnsupportedError('createTask');
}