deleteQueue method
Deletes a queue.
This command will delete the queue even if it has tasks in it.
Note: If you delete a queue, a queue with the same name can't be created for 7 days.
WARNING: Using this method may have unintended side effects if you are
using an App Engine queue.yaml or queue.xml file to manage your queues.
Read
Overview of Queue Management and
queue.yaml before using
this method.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
@override
Future<void> deleteQueue(DeleteQueueRequest request) async {
if (isClosed) throw StateError('Service is closed');
if (_deleteQueue case final deleteQueue?) {
return deleteQueue(request);
}
throw UnsupportedError('deleteQueue');
}