listTasks method

  1. @override
Future<ListTasksResponse> listTasks(
  1. ListTasksRequest request
)
override

Lists the tasks in a queue.

By default, only the BASIC view is retrieved due to performance considerations; response_view controls the subset of information which is returned.

The tasks may be returned in any order. The ordering may change at any time.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListTasksResponse> listTasks(ListTasksRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listTasks case final listTasks?) {
    return listTasks(request);
  }
  throw UnsupportedError('listTasks');
}