pauseQueue method

  1. @override
Future<Queue> pauseQueue(
  1. PauseQueueRequest request
)
override

Pauses the queue.

If a queue is paused then the system will stop dispatching tasks until the queue is resumed via ResumeQueue. Tasks can still be added when the queue is paused. A queue is paused if its state is PAUSED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Queue> pauseQueue(PauseQueueRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_pauseQueue case final pauseQueue?) {
    return pauseQueue(request);
  }
  throw UnsupportedError('pauseQueue');
}