setIamPolicy method

  1. @override
Future<Policy> setIamPolicy(
  1. SetIamPolicyRequest request
)
override

Sets the access control policy for a Queue. Replaces any existing policy.

Note: The Cloud Console does not check queue-level IAM permissions yet. Project-level permissions are required to use the Cloud Console.

Authorization requires the following Google IAM permission on the specified resource parent:

  • cloudtasks.queues.setIamPolicy

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<Policy> setIamPolicy(SetIamPolicyRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_setIamPolicy case final setIamPolicy?) {
    return setIamPolicy(request);
  }
  throw UnsupportedError('setIamPolicy');
}