AppEngineHttpRequest class final
App Engine HTTP request.
The message defines the HTTP request that is sent to an App Engine app when the task is dispatched.
Using AppEngineHttpRequest
requires
appengine.applications.get
Google IAM permission for the project
and the following scope:
https://www.googleapis.com/auth/cloud-platform
The task will be delivered to the App Engine app which belongs to the same project as the queue. For more information, see How Requests are Routed and how routing is affected by dispatch files. Traffic is encrypted during transport and never leaves Google datacenters. Because this traffic is carried over a communication mechanism internal to Google, you cannot explicitly set the protocol (for example, HTTP or HTTPS). The request to the handler, however, will appear to have used the HTTP protocol.
The AppEngineRouting used to
construct the URL that the task is delivered to can be set at the queue-level
or task-level:
- If
google.cloud.tasks.v2.Queue.app_engine_routing_override, this value is used for all tasks in the queue, no matter what the setting is for thegoogle.cloud.tasks.v2.AppEngineHttpRequest.app_engine_routing.
The url that the task will be sent to is:
url =host+relative_uri
Tasks can be dispatched to secure app handlers, unsecure app handlers, and
URIs restricted with
login: admin.
Because tasks are not run as any user, they cannot be dispatched to URIs
restricted with
login: required
Task dispatches also do not follow redirects.
The task attempt has succeeded if the app's request handler returns an HTTP
response code in the range `200` - `299`. The task attempt has failed if
the app's handler returns a non-2xx response code or Cloud Tasks does
not receive response before the
deadline. Failed tasks will
be retried according to the google.cloud.tasks.v2.Queue.retry_config. 503 (Service
Unavailable) is considered an App Engine system error instead of an
application error and will cause Cloud Tasks' traffic congestion control to
temporarily throttle the queue's dispatches. Unlike other types of task
targets, a 429 (Too Many Requests) response from an app handler does not
cause traffic congestion control to throttle the queue.
Constructors
-
AppEngineHttpRequest({HttpMethod httpMethod = HttpMethod.$default, AppEngineRouting? appEngineRouting, String relativeUri = '', Map<
String, String> headers = const {}, Uint8List? body}) - AppEngineHttpRequest.fromJson(Object? j)
-
factory
Properties
- appEngineRouting → AppEngineRouting?
-
Task-level setting for App Engine routing.
final
- body → Uint8List
-
HTTP request body.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
HTTP request headers.
final
- httpMethod → HttpMethod
-
The HTTP method to use for the request. The default is POST.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - relativeUri → String
-
The relative URI.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String