body property
HTTP request body.
A request body is allowed only if the HTTP method is POST or PUT. It is
an error to set a body on a task with an incompatible
HttpMethod.
Implementation
final Uint8List body;
HTTP request body.
A request body is allowed only if the HTTP method is POST or PUT. It is
an error to set a body on a task with an incompatible
HttpMethod.
final Uint8List body;