headers property
HTTP request headers.
This map contains the header field names and values.
Headers can be set when the
google.cloud.tasks.v2.CloudTasks.CreateTask.
Repeated headers are not supported but a header value can contain commas.
Cloud Tasks sets some headers to default values:
User-Agent: By default, this header is"AppEngine-Google; (+http://code.google.com/appengine)". This header can be modified, but Cloud Tasks will append"AppEngine-Google; (+http://code.google.com/appengine)"to the modifiedUser-Agent.
If the task has a body,
Cloud Tasks sets the following headers:
Content-Type: By default, theContent-Typeheader is set to"application/octet-stream". The default can be overridden by explicitly settingContent-Typeto a particular media type when thegoogle.cloud.tasks.v2.CloudTasks.CreateTask. For example,Content-Typecan be set to"application/json".Content-Length: This is computed by Cloud Tasks. This value is output only. It cannot be changed.
The headers below cannot be set or overridden:
HostX-Google-*X-AppEngine-*
In addition, Cloud Tasks sets some headers when the task is dispatched, such as headers containing information about the task; see request headers. These headers are set only when the task is dispatched, so they are not visible when the task is returned in a Cloud Tasks response.
Although there is no specific limit for the maximum number of headers or
the size, there is a limit on the maximum size of the
Task. For more information, see the
CreateTask documentation.
Implementation
final Map<String, String> headers;