deleteTask method
Deletes a task.
A task can be deleted if it is scheduled or dispatched. A task cannot be deleted if it has executed successfully or permanently failed.
Throws a http.ClientException if there were problems communicating with
the API service. Throws a ServiceException if the API method failed for
any reason.
Implementation
Future<void> deleteTask(DeleteTaskRequest request) async {
final url = _endPoint.replace(path: '/v2/${request.name}');
await _client.delete(url);
}