parent property
Required. The location name in which the queue will be created.
For example: projects/PROJECT_ID/locations/LOCATION_ID
The list of allowed locations can be obtained by calling Cloud
Tasks' implementation of
ListLocations.
Implementation
final String parent;