Queue class final
A queue is a container of related tasks. Queues are configured to manage how those tasks are dispatched. Configurable properties include rate limits, retry options, queue types, and others.
Constructors
- Queue({String name = '', AppEngineRouting? appEngineRoutingOverride, RateLimits? rateLimits, RetryConfig? retryConfig, Queue_State state = Queue_State.$default, Timestamp? purgeTime, StackdriverLoggingConfig? stackdriverLoggingConfig})
- Queue.fromJson(Object? j)
-
factory
Properties
- appEngineRoutingOverride → AppEngineRouting?
-
Overrides for
google.cloud.tasks.v2.AppEngineHttpRequest.app_engine_routing. These settings apply only togoogle.cloud.tasks.v2.AppEngineHttpRequestin this queue.google.cloud.tasks.v2.HttpRequestare not affected.final - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Caller-specified and required in
CreateQueue, after which it becomes output only.final - purgeTime → Timestamp?
-
Output only. The last time this queue was purged.
final
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - rateLimits → RateLimits?
-
Rate limits for task dispatches.
final
- retryConfig → RetryConfig?
-
Settings that determine the retry behavior.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackdriverLoggingConfig → StackdriverLoggingConfig?
-
Configuration options for writing logs to
Stackdriver Logging. If this
field is unset, then no logs are written.
final
- state → Queue_State
-
Output only. The state of the queue.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String