Queue_State class final
State of the queue.
Constructors
- Queue_State(String value)
-
const
- Queue_State.fromJson(Object? json)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNotDefault → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object? -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- $default → const Queue_State
- The default value for Queue_State.
- disabled → const Queue_State
- The queue is disabled.
- paused → const Queue_State
- Tasks are paused by the user. If the queue is paused then Cloud Tasks will stop delivering tasks from it, but more tasks can still be added to it by the user.
- running → const Queue_State
- The queue is running. Tasks can be dispatched.
- stateUnspecified → const Queue_State
- Unspecified state.