paused constant
Queue_State
const paused
Tasks are paused by the user. If the queue is paused then Cloud Tasks will stop delivering tasks from it, but more tasks can still be added to it by the user.
Implementation
static const paused = Queue_State('PAUSED');