maxDispatchesPerSecond property
The maximum rate at which tasks are dispatched from this queue.
If unspecified when the queue is created, Cloud Tasks will pick the default.
- The maximum allowed value is 500.
This field has the same meaning as rate in queue.yaml/xml.
Implementation
final double maxDispatchesPerSecond;