StackdriverLoggingConfig class final
Configuration options for writing logs to Stackdriver Logging.
Constructors
- StackdriverLoggingConfig({double samplingRatio = 0})
- StackdriverLoggingConfig.fromJson(Object? j)
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingRatio → double
-
Specifies the fraction of operations to write to
Stackdriver Logging.
This field may contain any value between 0.0 and 1.0, inclusive.
0.0 is the default and means that no operations are logged.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String