Task class final
A unit of scheduled work.
Constructors
- Task({String name = '', AppEngineHttpRequest? appEngineHttpRequest, HttpRequest? httpRequest, Timestamp? scheduleTime, Timestamp? createTime, Duration? dispatchDeadline, int dispatchCount = 0, int responseCount = 0, Attempt? firstAttempt, Attempt? lastAttempt, Task_View view = Task_View.$default})
- Task.fromJson(Object? j)
-
factory
Properties
- appEngineHttpRequest → AppEngineHttpRequest?
-
HTTP request that is sent to the App Engine app handler.
final
- createTime → Timestamp?
-
Output only. The time that the task was created.
final
- dispatchCount → int
-
Output only. The number of attempts dispatched.
final
- dispatchDeadline → Duration?
-
The deadline for requests sent to the worker. If the worker does not
respond by this deadline then the request is cancelled and the attempt
is marked as a
DEADLINE_EXCEEDEDfailure. Cloud Tasks will retry the task according to theRetryConfig.final - firstAttempt → Attempt?
-
Output only. The status of the task's first attempt.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpRequest → HttpRequest?
-
HTTP request that is sent to the worker.
final
- lastAttempt → Attempt?
-
Output only. The status of the task's last attempt.
final
- name → String
-
Optionally caller-specified in
CreateTask.final - qualifiedName → String
-
The fully qualified name of this message, i.e.,
google.protobuf.Durationorgoogle.rpc.ErrorInfo.finalinherited - responseCount → int
-
Output only. The number of attempts which have received a response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduleTime → Timestamp?
-
The time when the task is scheduled to be attempted or retried.
final
- view → Task_View
-
Output only. The view specifies which subset of the
Taskhas been returned.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fullyQualifiedName → const String